module: increments — pydartlab 0.0.1 documentation

# module: increments

exception increments.InvalidVarianceError

  Exception raised for errors in the input variance.

increments.obs_increment_eakf(ensemble, observation, obs_error_var)

  Computes increments for an ensemble adjustment Kalman filter (EAKF).

  Parameters: - ensemble: numpy array representing the ensemble of prior state estimates. - observation: scalar representing the observation. - obs_error_var: scalar representing the observation error variance.

  Raises: - InvalidVarianceError: If both prior and observation error variance are <= 0.

  Returns: - obs_increments: numpy array representing the observation increments.

increments.obs_increment_enkf(ensemble, observation, obs_error_var)

  Computes increments for an ensemble Kalman filter with perturbed obs mean correction.

  Parameters: - ensemble: numpy array representing the ensemble of prior state estimates. - observation: scalar representing the observation. - obs_error_var: scalar representing the observation error variance.

  Raises: - InvalidVarianceError: If both prior and observation error variance <= 0.

  Returns: - obs_increments: numpy array representing the observation increments.

increments.obs_increment_rhf(ensemble, observation, obs_error_var)

  Computes increments for a rank histogram filter.

increments.weighted_norm_inv(alpha, mean, sd, p)

  Find the value of x for which the cdf of a N(mean, sd) multiplied times alpha has value p.